@@ -12,8 +12,11 @@ use namespace::autoclean;
 
 use HPCD::SGE::Stage;
 
-with 'HPCI::Group' => { theDriver => 'HPCD::SGE' },
-    'HPCD::SGE::JobGroup';
+
+with
+	'HPCI::Group'    => { theDriver => 'HPCD::SGE' },
+	'HPCD::SGE::JobGroup',
+	HPCI::get_extra_roles('SGE', 'group');
 
 1;
 
